Documentation
¶
Index ¶
- type CronJobFiredPayload
- type JobStatus
- type OrchestratorClient
- type Service
- func (s *Service) ListJobs() []JobStatus
- func (s *Service) Reload(cfg config.CronJobsConfig) error
- func (s *Service) RunNow(ctx context.Context, name string) (*mesnadamodels.Task, error)
- func (s *Service) Start(ctx context.Context, cfg config.CronJobsConfig) error
- func (s *Service) Stop()
- func (s *Service) Subscribe(ctx context.Context) <-chan pubsub.Event[CronJobFiredPayload]
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CronJobFiredPayload ¶
CronJobFiredPayload is published via pubsub whenever a scheduled or manual cronjob dispatch succeeds and a Mesnada task has been created.
type OrchestratorClient ¶
type OrchestratorClient interface {
Spawn(ctx context.Context, req mesnadamodels.SpawnRequest) (*mesnadamodels.Task, error)
ListTasks(req mesnadamodels.ListRequest) ([]*mesnadamodels.Task, error)
}
Click to show internal directories.
Click to hide internal directories.