chat

package
v0.411.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: MIT Imports: 41 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DeleteKeyMaps = DeleteAttachmentKeyMaps{
	AttachmentDeleteMode: key.NewBinding(
		key.WithKeys("ctrl+shift+r"),
		key.WithHelp("ctrl+shift+r+{i}", "delete attachment at index i"),
	),
	Escape: key.NewBinding(
		key.WithKeys("esc"),
		key.WithHelp("esc", "cancel delete mode"),
	),
	DeleteAllAttachments: key.NewBinding(
		key.WithKeys("r"),
		key.WithHelp("ctrl+r+r", "delete all attchments"),
	),
}

Functions

func CreateTextArea

func CreateTextArea(existing *textarea.Model) textarea.Model

func NewEditorCmp

func NewEditorCmp(app *app.App) tea.Model

func NewGoalStatusCmp added in v0.324.0

func NewGoalStatusCmp() tea.Model

func NewMessagesCmp

func NewMessagesCmp(app *app.App) tea.Model

func NewSidebarCmp

func NewSidebarCmp(session session.Session, history history.Service) tea.Model

Types

type BlurChatEditorMsg added in v0.3.0

type BlurChatEditorMsg struct{}

BlurChatEditorMsg is sent to the chat editor to relinquish textarea focus.

type CompactSessionMsg added in v0.410.1

type CompactSessionMsg struct{}

CompactSessionMsg requests a manual compaction of the current session.

type DeleteAttachmentKeyMaps

type DeleteAttachmentKeyMaps struct {
	AttachmentDeleteMode key.Binding
	Escape               key.Binding
	DeleteAllAttachments key.Binding
}

type EditorFocusMsg

type EditorFocusMsg bool

type EditorKeyMaps

type EditorKeyMaps struct {
	Send        key.Binding
	NewLine     key.Binding
	OpenEditor  key.Binding
	HistoryPrev key.Binding
	HistoryNext key.Binding
}

type FocusChatEditorMsg added in v0.3.0

type FocusChatEditorMsg struct{}

FocusChatEditorMsg is sent to the chat editor to request textarea focus.

type GoalState added in v0.324.0

type GoalState struct {
	Objective      string
	Status         string
	Iteration      int64
	MaxIterations  int64
	StartedAt      int64
	CompletedAt    int64
	HasCompletedAt bool
	Progress       string
	NextStep       string
}

GoalState is the TUI-friendly projection of the current goal/autopilot state.

func (*GoalState) IsRunning added in v0.324.0

func (g *GoalState) IsRunning() bool

func (*GoalState) IsTerminal added in v0.324.0

func (g *GoalState) IsTerminal() bool

type GoalUpdatedMsg added in v0.324.0

type GoalUpdatedMsg struct {
	SessionID string
	Goal      *GoalState
}

GoalUpdatedMsg is dispatched when the current session goal state changes.

type MessageKeys

type MessageKeys struct {
	PageDown     key.Binding
	PageUp       key.Binding
	HalfPageUp   key.Binding
	HalfPageDown key.Binding
}

type SendMsg

type SendMsg struct {
	Text        string
	Attachments []message.Attachment
}

type SessionClearedMsg

type SessionClearedMsg struct{}

type SessionSelectedMsg

type SessionSelectedMsg = session.Session

type ShowSlashCompletionMsg added in v0.410.1

type ShowSlashCompletionMsg struct{}

ShowSlashCompletionMsg is emitted when "/" is typed at the start of an empty editor.

type TodosUpdatedMsg added in v0.257.0

type TodosUpdatedMsg struct {
	SessionID string
	Todos     []tools.TodoItem
}

TodosUpdatedMsg is dispatched when the TodoWrite tool updates the plan.

Jump to