evaluator

package
v0.256.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MetricsComponent

type MetricsComponent interface {
	tea.Model
	View() string
}

MetricsComponent is the public interface for the evaluator metrics header.

func NewMetricsCmp

func NewMetricsCmp(stats *evaluator.Stats) MetricsComponent

NewMetricsCmp creates a new metrics header component.

type SkillsComponent

type SkillsComponent interface {
	tea.Model
	layout.Sizeable
	layout.Bindings
}

SkillsComponent is the public interface for the skill library list.

func NewSkillsCmp

func NewSkillsCmp(skills []evaluator.Skill) SkillsComponent

NewSkillsCmp creates a new skills list component.

type TableComponent

type TableComponent interface {
	tea.Model
	layout.Sizeable
	layout.Bindings
}

TableComponent is the public interface for the evaluator template table.

func NewTableCmp

func NewTableCmp(templates []evaluator.TemplateStats) TableComponent

NewTableCmp creates a new template ranking table component.

Jump to