page

package
v0.411.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: MIT Imports: 45 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewInstancesPage added in v0.294.1

func NewInstancesPage() tea.Model

NewInstancesPage creates a new instances browser page.

func NewOrchestratorPage

func NewOrchestratorPage(app *app.App) tea.Model

func NewSettingsPage

func NewSettingsPage(app *pandoapp.App) tea.Model

Types

type ChatKeyMap

type ChatKeyMap struct {
	ShowCompletionDialog      key.Binding
	ShowSlashCompletionDialog key.Binding
	NewSession                key.Binding
	Cancel                    key.Binding
	ToggleSidebar             key.Binding
	NextPanel                 key.Binding
	ToggleEditorChat          key.Binding
}

type ChatLayoutMode added in v0.2.0

type ChatLayoutMode int
const (
	ChatOnly ChatLayoutMode = iota
	SidebarChat
	SidebarEditor
	EditorChatSplit
	EditorChatTab
)

type ChatPageModel added in v0.2.0

type ChatPageModel struct {
	// contains filtered or unexported fields
}

func NewChatPage

func NewChatPage(app *app.App) *ChatPageModel

func (*ChatPageModel) BindingKeys added in v0.2.0

func (p *ChatPageModel) BindingKeys() []key.Binding

func (*ChatPageModel) FileTree added in v0.2.0

func (p *ChatPageModel) FileTree() filetree.Component

func (*ChatPageModel) GetSize added in v0.2.0

func (p *ChatPageModel) GetSize() (int, int)

func (*ChatPageModel) HasRunningGoal added in v0.324.0

func (p *ChatPageModel) HasRunningGoal() bool

func (*ChatPageModel) Init added in v0.2.0

func (p *ChatPageModel) Init() tea.Cmd

func (*ChatPageModel) LayoutMode added in v0.2.0

func (p *ChatPageModel) LayoutMode() ChatLayoutMode

func (*ChatPageModel) SetSize added in v0.2.0

func (p *ChatPageModel) SetSize(width, height int) tea.Cmd

func (*ChatPageModel) TabBar added in v0.2.0

func (p *ChatPageModel) TabBar() *editor.TabBar

func (*ChatPageModel) Update added in v0.2.0

func (p *ChatPageModel) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (*ChatPageModel) View added in v0.2.0

func (p *ChatPageModel) View() string

func (*ChatPageModel) Viewer added in v0.2.0

type EvaluatorPageModel added in v0.26.2

type EvaluatorPageModel interface {
	tea.Model
	layout.Sizeable
	layout.Bindings
}

EvaluatorPageModel is the public interface for the self-improvement page.

func NewEvaluatorPage added in v0.26.2

func NewEvaluatorPage(svc evaluator.Service) EvaluatorPageModel

NewEvaluatorPage creates and returns a new self-improvement evaluator page.

type LogPage

type LogPage interface {
	tea.Model
	layout.Sizeable
	layout.Bindings
}

func NewLogsPage

func NewLogsPage() LogPage

type ModalPage added in v0.40.0

type ModalPage interface {
	HasActiveModal() bool
	ClearModals()
}

ModalPage is implemented by pages that host modal dialogs, allowing the app-level key handler to check whether a modal is active before intercepting navigation keys like Esc.

type OrchestratorFilterMsg added in v0.244.0

type OrchestratorFilterMsg struct {
	Tag string
}

OrchestratorFilterMsg asks the orchestrator page to apply a tag filter and navigate to it.

type PageChangeMsg

type PageChangeMsg struct {
	ID PageID
}

PageChangeMsg is used to change the current page

type PageID

type PageID string
const (
	ChatPage         PageID = "chat"
	LogsPage         PageID = "logs"
	SettingsPage     PageID = "settings"
	OrchestratorPage PageID = "orchestrator"
	SnapshotsPage    PageID = "snapshots"
	EvaluatorPage    PageID = "evaluator"
)
const InstancesPage PageID = "instances"

InstancesPage is the page.PageID for the instance browser.

type SnapshotPage added in v0.26.2

type SnapshotPage interface {
	tea.Model
	layout.Sizeable
	layout.Bindings
}

SnapshotPage is the public interface for the snapshots page.

func NewSnapshotsPage added in v0.26.2

func NewSnapshotsPage(app *app.App) SnapshotPage

NewSnapshotsPage creates and returns a new snapshots page.

type TagFilterable added in v0.244.0

type TagFilterable interface {
	SetFilterTag(tag string)
}

TagFilterable is implemented by pages that support tag-based task filtering.

Jump to