Documentation
¶
Index ¶
- Constants
- Variables
- func AccentColor() lipgloss.AdaptiveColor
- func BackgroundColor() lipgloss.AdaptiveColor
- func BackgroundDarkerColor() lipgloss.AdaptiveColor
- func BackgroundSecondaryColor() lipgloss.AdaptiveColor
- func BaseStyle() lipgloss.Style
- func Bold() lipgloss.Style
- func Border() lipgloss.Style
- func BorderDimColor() lipgloss.AdaptiveColor
- func BorderFocusedColor() lipgloss.AdaptiveColor
- func BorderNormalColor() lipgloss.AdaptiveColor
- func DimBorder() lipgloss.Style
- func DoubleBorder() lipgloss.Style
- func ErrorColor() lipgloss.AdaptiveColor
- func FileIconFor(name string) string
- func FocusedBorder() lipgloss.Style
- func ForceReplaceBackgroundWithLipgloss(input string, newBgColor lipgloss.TerminalColor) string
- func GetMarkdownRenderer(width int) *glamour.TermRenderer
- func InfoColor() lipgloss.AdaptiveColor
- func Padded() lipgloss.Style
- func PrimaryColor() lipgloss.AdaptiveColor
- func Regular() lipgloss.Style
- func SecondaryColor() lipgloss.AdaptiveColor
- func SuccessColor() lipgloss.AdaptiveColor
- func TextColor() lipgloss.AdaptiveColor
- func TextEmphasizedColor() lipgloss.AdaptiveColor
- func TextMutedColor() lipgloss.AdaptiveColor
- func ThickBorder() lipgloss.Style
- func WarningColor() lipgloss.AdaptiveColor
Constants ¶
const ( PandoIcon string = "木" OpenCodeIcon = PandoIcon // Diagnostics CheckIcon string = "" ErrorIcon string = "" WarningIcon string = "" InfoIcon string = "" HintIcon string = "" // Status SpinnerIcon string = "" LoadingIcon string = "" SuccessIcon string = "" FailureIcon string = "" // Files & documents DocumentIcon string = "" FileIcon string = "" FolderIcon string = "" FolderOpenIcon string = "" // Git GitBranchIcon string = "" GitCommitIcon string = "" GitMergeIcon string = "" GitAddedIcon string = "" GitRemovedIcon string = "" GitModifiedIcon string = "" // Navigation ArrowRightIcon string = "" ArrowDownIcon string = "" ChevronRight string = "" ChevronDown string = "" ChevronLeft string = "" ChevronUp string = "" // UI SearchIcon string = "" SettingsIcon string = "" ChatIcon string = "" TerminalIcon string = "" CloseIcon string = "" PlusIcon string = "" MinusIcon string = "" LockIcon string = "" UnlockIcon string = "" ClipboardIcon string = "" BookmarkIcon string = "" // Provider / AI RobotIcon string = "" AIIcon string = "" BrainIcon string = "" MagicIcon string = "" // Misc BugIcon string = "" FlameIcon string = "" LightbulbIcon string = "" ClockIcon string = "" CalendarIcon string = "" TagIcon string = "" LinkIcon string = "" KeyIcon string = "" ShieldIcon string = "" DatabaseIcon string = "" CloudIcon string = "" PackageIcon string = "" )
Variables ¶
var (
ImageBakcground = "#212121"
)
var SpinnerFrames = []string{"⠋", "⠙", "⠹", "⠸", "⠼", "⠴", "⠦", "⠧", "⠇", "⠏"}
Functions ¶
func AccentColor ¶
func AccentColor() lipgloss.AdaptiveColor
AccentColor returns the accent color from the current theme
func BackgroundColor ¶
func BackgroundColor() lipgloss.AdaptiveColor
BackgroundColor returns the background color from the current theme
func BackgroundDarkerColor ¶
func BackgroundDarkerColor() lipgloss.AdaptiveColor
BackgroundDarkerColor returns the darker background color from the current theme
func BackgroundSecondaryColor ¶
func BackgroundSecondaryColor() lipgloss.AdaptiveColor
BackgroundSecondaryColor returns the secondary background color from the current theme
func BorderDimColor ¶
func BorderDimColor() lipgloss.AdaptiveColor
BorderDimColor returns the dim border color from the current theme
func BorderFocusedColor ¶
func BorderFocusedColor() lipgloss.AdaptiveColor
BorderFocusedColor returns the focused border color from the current theme
func BorderNormalColor ¶
func BorderNormalColor() lipgloss.AdaptiveColor
BorderNormalColor returns the normal border color from the current theme
func DoubleBorder ¶
DoubleBorder returns a style with a double border
func ErrorColor ¶
func ErrorColor() lipgloss.AdaptiveColor
ErrorColor returns the error color from the current theme
func FileIconFor ¶ added in v0.2.0
func FocusedBorder ¶
FocusedBorder returns a style with a border using the focused border color
func ForceReplaceBackgroundWithLipgloss ¶
func ForceReplaceBackgroundWithLipgloss(input string, newBgColor lipgloss.TerminalColor) string
ForceReplaceBackgroundWithLipgloss replaces any ANSI background color codes in `input` with a single 24‑bit background (48;2;R;G;B).
func GetMarkdownRenderer ¶
func GetMarkdownRenderer(width int) *glamour.TermRenderer
returns a glamour TermRenderer configured with the current theme
func InfoColor ¶
func InfoColor() lipgloss.AdaptiveColor
InfoColor returns the info color from the current theme
func PrimaryColor ¶
func PrimaryColor() lipgloss.AdaptiveColor
PrimaryColor returns the primary color from the current theme
func SecondaryColor ¶
func SecondaryColor() lipgloss.AdaptiveColor
SecondaryColor returns the secondary color from the current theme
func SuccessColor ¶
func SuccessColor() lipgloss.AdaptiveColor
SuccessColor returns the success color from the current theme
func TextColor ¶
func TextColor() lipgloss.AdaptiveColor
TextColor returns the text color from the current theme
func TextEmphasizedColor ¶
func TextEmphasizedColor() lipgloss.AdaptiveColor
TextEmphasizedColor returns the emphasized text color from the current theme
func TextMutedColor ¶
func TextMutedColor() lipgloss.AdaptiveColor
TextMutedColor returns the muted text color from the current theme
func ThickBorder ¶
ThickBorder returns a style with a thick border
func WarningColor ¶
func WarningColor() lipgloss.AdaptiveColor
WarningColor returns the warning color from the current theme
Types ¶
This section is empty.