Documentation
¶
Index ¶
- func AlertError(msg string) tea.Cmd
- func AlertInfo(msg string) tea.Cmd
- func AlertPersist(alertType, msg string) tea.Cmd
- func AlertWarn(msg string) tea.Cmd
- func Clamp(v, low, high int) int
- func CmdHandler(msg tea.Msg) tea.Cmd
- func ReportError(err error) tea.Cmd
- func ReportInfo(info string) tea.Cmd
- func ReportWarn(warn string) tea.Cmd
- type AlertMsg
- type ClearStatusMsg
- type InfoMsg
- type InfoType
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AlertError ¶ added in v0.2.0
AlertError creates a bubbleup error overlay alert.
func AlertPersist ¶ added in v0.2.0
AlertPersist creates a persistent bubbleup alert that stays until Esc is pressed.
func ReportError ¶
func ReportInfo ¶
func ReportWarn ¶
Types ¶
type AlertMsg ¶ added in v0.2.0
type AlertMsg struct {
Type string // bubbleup alert key: "Info", "Warn", "Error"
Msg string
Persist bool // if true, alert stays until dismissed with Esc
}
AlertMsg triggers a bubbleup overlay alert instead of the status bar.
type ClearStatusMsg ¶
type ClearStatusMsg struct{}
Click to show internal directories.
Click to hide internal directories.