version

package
v0.408.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 30, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = "unknown"

Build-time parameters set via -ldflags

Functions

func Canonical added in v0.400.0

func Canonical() string

Canonical returns the version with a leading v when the current value is a semver.

func Parse added in v0.400.0

func Parse(v string) (semver.Version, bool)

Parse parses a version string that may be prefixed with 'v'.

func Semver added in v0.400.0

func Semver() (semver.Version, bool)

Semver returns the current version parsed as semantic version.

Types

This section is empty.

Jump to