Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetEvaluator ¶ added in v0.26.2
func SetEvaluator(e evaluatorService)
SetEvaluator sets the evaluator service used to trigger self-evaluation at session end.
func SetIPCPublisher ¶ added in v0.294.1
func SetIPCPublisher(p IPCPublisher)
SetIPCPublisher sets the ZMQ IPC publisher for cross-instance event broadcasting. Call this from app.go after the Bus is started (only for the primary instance).
func SetLuaManager ¶ added in v0.8.0
func SetLuaManager(fm *luaengine.FilterManager)
SetLuaManager sets the Lua filter manager used for session lifecycle hooks.
func SetSnapshotCreator ¶ added in v0.26.2
func SetSnapshotCreator(sc SnapshotCreator)
SetSnapshotCreator sets the snapshot creator used for session lifecycle snapshots.
Types ¶
type IPCPublisher ¶ added in v0.294.1
IPCPublisher is the minimal interface used by session to publish ZMQ events. A local interface is used to avoid import cycles between session and ipc packages.
type Service ¶
type Service interface {
pubsub.Suscriber[Session]
Create(ctx context.Context, title string) (Session, error)
CreateTitleSession(ctx context.Context, parentSessionID string) (Session, error)
CreateTaskSession(ctx context.Context, toolCallID, parentSessionID, title string) (Session, error)
GetACPSessionState(ctx context.Context, sessionID string) (string, error)
Get(ctx context.Context, id string) (Session, error)
List(ctx context.Context) ([]Session, error)
SaveACPSessionState(ctx context.Context, sessionID string, state string) error
Save(ctx context.Context, session Session) (Session, error)
Delete(ctx context.Context, id string) error
EndSession(ctx context.Context, id string) error
}
func NewService ¶
Click to show internal directories.
Click to hide internal directories.