Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetEvaluator ¶ added in v0.26.2
func SetEvaluator(e evaluatorService)
SetEvaluator sets the evaluator service used to trigger self-evaluation at session end.
func SetLuaManager ¶ added in v0.8.0
func SetLuaManager(fm *luaengine.FilterManager)
SetLuaManager sets the Lua filter manager used for session lifecycle hooks.
func SetSnapshotCreator ¶ added in v0.26.2
func SetSnapshotCreator(sc SnapshotCreator)
SetSnapshotCreator sets the snapshot creator used for session lifecycle snapshots.
Types ¶
type Service ¶
type Service interface {
pubsub.Suscriber[Session]
Create(ctx context.Context, title string) (Session, error)
CreateTitleSession(ctx context.Context, parentSessionID string) (Session, error)
CreateTaskSession(ctx context.Context, toolCallID, parentSessionID, title string) (Session, error)
Get(ctx context.Context, id string) (Session, error)
List(ctx context.Context) ([]Session, error)
Save(ctx context.Context, session Session) (Session, error)
Delete(ctx context.Context, id string) error
EndSession(ctx context.Context, id string) error
}
func NewService ¶
Click to show internal directories.
Click to hide internal directories.