Documentation
¶
Index ¶
- Variables
- func CreateTextArea(existing *textarea.Model) textarea.Model
- func NewEditorCmp(app *app.App) tea.Model
- func NewGoalStatusCmp() tea.Model
- func NewMessagesCmp(app *app.App) tea.Model
- func NewSidebarCmp(session session.Session, history history.Service) tea.Model
- type BlurChatEditorMsg
- type CompactSessionMsg
- type DeleteAttachmentKeyMaps
- type EditorFocusMsg
- type EditorKeyMaps
- type FocusChatEditorMsg
- type GoalState
- type GoalUpdatedMsg
- type MessageKeys
- type SendMsg
- type SessionClearedMsg
- type SessionSelectedMsg
- type ShowSlashCompletionMsg
- type TodosUpdatedMsg
Constants ¶
This section is empty.
Variables ¶
var DeleteKeyMaps = DeleteAttachmentKeyMaps{ AttachmentDeleteMode: key.NewBinding( key.WithKeys("ctrl+shift+r"), key.WithHelp("ctrl+shift+r+{i}", "delete attachment at index i"), ), Escape: key.NewBinding( key.WithKeys("esc"), key.WithHelp("esc", "cancel delete mode"), ), DeleteAllAttachments: key.NewBinding( key.WithKeys("r"), key.WithHelp("ctrl+r+r", "delete all attchments"), ), }
Functions ¶
func NewGoalStatusCmp ¶ added in v0.324.0
Types ¶
type BlurChatEditorMsg ¶ added in v0.3.0
type BlurChatEditorMsg struct{}
BlurChatEditorMsg is sent to the chat editor to relinquish textarea focus.
type CompactSessionMsg ¶ added in v0.410.1
type CompactSessionMsg struct{}
CompactSessionMsg requests a manual compaction of the current session.
type DeleteAttachmentKeyMaps ¶
type EditorFocusMsg ¶
type EditorFocusMsg bool
type EditorKeyMaps ¶
type FocusChatEditorMsg ¶ added in v0.3.0
type FocusChatEditorMsg struct{}
FocusChatEditorMsg is sent to the chat editor to request textarea focus.
type GoalState ¶ added in v0.324.0
type GoalState struct {
Objective string
Status string
Iteration int64
MaxIterations int64
StartedAt int64
CompletedAt int64
HasCompletedAt bool
Progress string
NextStep string
}
GoalState is the TUI-friendly projection of the current goal/autopilot state.
func (*GoalState) IsTerminal ¶ added in v0.324.0
type GoalUpdatedMsg ¶ added in v0.324.0
GoalUpdatedMsg is dispatched when the current session goal state changes.
type MessageKeys ¶
type SendMsg ¶
type SendMsg struct {
Text string
Attachments []message.Attachment
}
type SessionClearedMsg ¶
type SessionClearedMsg struct{}
type SessionSelectedMsg ¶
type ShowSlashCompletionMsg ¶ added in v0.410.1
type ShowSlashCompletionMsg struct{}
ShowSlashCompletionMsg is emitted when "/" is typed at the start of an empty editor.
type TodosUpdatedMsg ¶ added in v0.257.0
TodosUpdatedMsg is dispatched when the TodoWrite tool updates the plan.
Click to show internal directories.
Click to hide internal directories.