chat

package
v0.245.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 41 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DeleteKeyMaps = DeleteAttachmentKeyMaps{
	AttachmentDeleteMode: key.NewBinding(
		key.WithKeys("ctrl+shift+r"),
		key.WithHelp("ctrl+shift+r+{i}", "delete attachment at index i"),
	),
	Escape: key.NewBinding(
		key.WithKeys("esc"),
		key.WithHelp("esc", "cancel delete mode"),
	),
	DeleteAllAttachments: key.NewBinding(
		key.WithKeys("r"),
		key.WithHelp("ctrl+r+r", "delete all attchments"),
	),
}

Functions

func CreateTextArea

func CreateTextArea(existing *textarea.Model) textarea.Model

func NewEditorCmp

func NewEditorCmp(app *app.App) tea.Model

func NewMessagesCmp

func NewMessagesCmp(app *app.App) tea.Model

func NewSidebarCmp

func NewSidebarCmp(session session.Session, history history.Service) tea.Model

Types

type BlurChatEditorMsg added in v0.3.0

type BlurChatEditorMsg struct{}

BlurChatEditorMsg is sent to the chat editor to relinquish textarea focus.

type DeleteAttachmentKeyMaps

type DeleteAttachmentKeyMaps struct {
	AttachmentDeleteMode key.Binding
	Escape               key.Binding
	DeleteAllAttachments key.Binding
}

type EditorFocusMsg

type EditorFocusMsg bool

type EditorKeyMaps

type EditorKeyMaps struct {
	Send        key.Binding
	NewLine     key.Binding
	OpenEditor  key.Binding
	HistoryPrev key.Binding
	HistoryNext key.Binding
}

type FocusChatEditorMsg added in v0.3.0

type FocusChatEditorMsg struct{}

FocusChatEditorMsg is sent to the chat editor to request textarea focus.

type MessageKeys

type MessageKeys struct {
	PageDown     key.Binding
	PageUp       key.Binding
	HalfPageUp   key.Binding
	HalfPageDown key.Binding
}

type SendMsg

type SendMsg struct {
	Text        string
	Attachments []message.Attachment
}

type SessionClearedMsg

type SessionClearedMsg struct{}

type SessionSelectedMsg

type SessionSelectedMsg = session.Session

Jump to