Documentation
¶
Index ¶
- Variables
- func CreateTextArea(existing *textarea.Model) textarea.Model
- func NewEditorCmp(app *app.App) tea.Model
- func NewMessagesCmp(app *app.App) tea.Model
- func NewSidebarCmp(session session.Session, history history.Service) tea.Model
- type BlurChatEditorMsg
- type DeleteAttachmentKeyMaps
- type EditorFocusMsg
- type EditorKeyMaps
- type FocusChatEditorMsg
- type MessageKeys
- type SendMsg
- type SessionClearedMsg
- type SessionSelectedMsg
Constants ¶
This section is empty.
Variables ¶
var DeleteKeyMaps = DeleteAttachmentKeyMaps{ AttachmentDeleteMode: key.NewBinding( key.WithKeys("ctrl+shift+r"), key.WithHelp("ctrl+shift+r+{i}", "delete attachment at index i"), ), Escape: key.NewBinding( key.WithKeys("esc"), key.WithHelp("esc", "cancel delete mode"), ), DeleteAllAttachments: key.NewBinding( key.WithKeys("r"), key.WithHelp("ctrl+r+r", "delete all attchments"), ), }
Functions ¶
Types ¶
type BlurChatEditorMsg ¶ added in v0.3.0
type BlurChatEditorMsg struct{}
BlurChatEditorMsg is sent to the chat editor to relinquish textarea focus.
type DeleteAttachmentKeyMaps ¶
type EditorFocusMsg ¶
type EditorFocusMsg bool
type EditorKeyMaps ¶
type FocusChatEditorMsg ¶ added in v0.3.0
type FocusChatEditorMsg struct{}
FocusChatEditorMsg is sent to the chat editor to request textarea focus.
type MessageKeys ¶
type SendMsg ¶
type SendMsg struct {
Text string
Attachments []message.Attachment
}
type SessionClearedMsg ¶
type SessionClearedMsg struct{}
type SessionSelectedMsg ¶
Click to show internal directories.
Click to hide internal directories.