Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MetricsComponent ¶
MetricsComponent is the public interface for the evaluator metrics header.
func NewMetricsCmp ¶
func NewMetricsCmp(stats *evaluator.Stats) MetricsComponent
NewMetricsCmp creates a new metrics header component.
type SkillsComponent ¶
SkillsComponent is the public interface for the skill library list.
func NewSkillsCmp ¶
func NewSkillsCmp(skills []evaluator.Skill) SkillsComponent
NewSkillsCmp creates a new skills list component.
type TableComponent ¶
TableComponent is the public interface for the evaluator template table.
func NewTableCmp ¶
func NewTableCmp(templates []evaluator.TemplateStats) TableComponent
NewTableCmp creates a new template ranking table component.
Click to show internal directories.
Click to hide internal directories.