Documentation
¶
Index ¶
- func NewOrchestratorPage(app *app.App) tea.Model
- func NewSettingsPage(app *pandoapp.App) tea.Model
- type ChatKeyMap
- type ChatLayoutMode
- type ChatPageModel
- func (p *ChatPageModel) BindingKeys() []key.Binding
- func (p *ChatPageModel) FileTree() filetree.Component
- func (p *ChatPageModel) GetSize() (int, int)
- func (p *ChatPageModel) Init() tea.Cmd
- func (p *ChatPageModel) LayoutMode() ChatLayoutMode
- func (p *ChatPageModel) SetSize(width, height int) tea.Cmd
- func (p *ChatPageModel) TabBar() *editor.TabBar
- func (p *ChatPageModel) Update(msg tea.Msg) (tea.Model, tea.Cmd)
- func (p *ChatPageModel) View() string
- func (p *ChatPageModel) Viewer() editor.FileViewerComponent
- type EvaluatorPageModel
- type LogPage
- type ModalPage
- type OrchestratorFilterMsg
- type PageChangeMsg
- type PageID
- type SnapshotPage
- type TagFilterable
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ChatKeyMap ¶
type ChatLayoutMode ¶ added in v0.2.0
type ChatLayoutMode int
const ( ChatOnly ChatLayoutMode = iota SidebarChat SidebarEditor EditorChatSplit EditorChatTab )
type ChatPageModel ¶ added in v0.2.0
type ChatPageModel struct {
// contains filtered or unexported fields
}
func NewChatPage ¶
func NewChatPage(app *app.App) *ChatPageModel
func (*ChatPageModel) BindingKeys ¶ added in v0.2.0
func (p *ChatPageModel) BindingKeys() []key.Binding
func (*ChatPageModel) FileTree ¶ added in v0.2.0
func (p *ChatPageModel) FileTree() filetree.Component
func (*ChatPageModel) GetSize ¶ added in v0.2.0
func (p *ChatPageModel) GetSize() (int, int)
func (*ChatPageModel) Init ¶ added in v0.2.0
func (p *ChatPageModel) Init() tea.Cmd
func (*ChatPageModel) LayoutMode ¶ added in v0.2.0
func (p *ChatPageModel) LayoutMode() ChatLayoutMode
func (*ChatPageModel) SetSize ¶ added in v0.2.0
func (p *ChatPageModel) SetSize(width, height int) tea.Cmd
func (*ChatPageModel) TabBar ¶ added in v0.2.0
func (p *ChatPageModel) TabBar() *editor.TabBar
func (*ChatPageModel) View ¶ added in v0.2.0
func (p *ChatPageModel) View() string
func (*ChatPageModel) Viewer ¶ added in v0.2.0
func (p *ChatPageModel) Viewer() editor.FileViewerComponent
type EvaluatorPageModel ¶ added in v0.26.2
EvaluatorPageModel is the public interface for the self-improvement page.
func NewEvaluatorPage ¶ added in v0.26.2
func NewEvaluatorPage(svc evaluator.Service) EvaluatorPageModel
NewEvaluatorPage creates and returns a new self-improvement evaluator page.
type LogPage ¶
func NewLogsPage ¶
func NewLogsPage() LogPage
type ModalPage ¶ added in v0.40.0
type ModalPage interface {
HasActiveModal() bool
ClearModals()
}
ModalPage is implemented by pages that host modal dialogs, allowing the app-level key handler to check whether a modal is active before intercepting navigation keys like Esc.
type OrchestratorFilterMsg ¶ added in v0.244.0
type OrchestratorFilterMsg struct {
Tag string
}
OrchestratorFilterMsg asks the orchestrator page to apply a tag filter and navigate to it.
type PageChangeMsg ¶
type PageChangeMsg struct {
ID PageID
}
PageChangeMsg is used to change the current page
type SnapshotPage ¶ added in v0.26.2
SnapshotPage is the public interface for the snapshots page.
func NewSnapshotsPage ¶ added in v0.26.2
func NewSnapshotsPage(app *app.App) SnapshotPage
NewSnapshotsPage creates and returns a new snapshots page.
type TagFilterable ¶ added in v0.244.0
type TagFilterable interface {
SetFilterTag(tag string)
}
TagFilterable is implemented by pages that support tag-based task filtering.